@@ -23,12 +23,12 @@
 #include "konsolekalendar_debug.h"
 #include <KLocalizedString>
 
-#include <AkonadiCore/AgentInstance>
-#include <AkonadiCore/AgentInstanceCreateJob>
-#include <AkonadiCore/AgentManager>
-#include <AkonadiCore/Collection>
-#include <AkonadiCore/CollectionFetchJob>
-#include <AkonadiCore/CollectionFetchScope>
+#include <Akonadi/AgentInstance>
+#include <Akonadi/AgentInstanceCreateJob>
+#include <Akonadi/AgentManager>
+#include <Akonadi/Collection>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/CollectionFetchScope>
 #include <KCalUtils/HtmlExport>
 #include <kcalutils/htmlexportsettings.h>
 
@@ -252,7 +252,8 @@ bool KonsoleKalendar::showInstance()
                     }
                 }
             } else {
-                QDate firstdate, lastdate;
+                QDate firstdate;
+                QDate lastdate;
                 if (m_variables->getAll()) {
                     qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendar.cpp::showInstance() |"
                                                  << "HTML view all events sorted list";
