@@ -26,9 +26,8 @@
 #include <KCalendarCore/FileStorage>
 
 #include <Akonadi/Calendar/IncidenceChanger>
-#include <AkonadiCore/Collection>
+#include <Akonadi/Collection>
 
-#include <QDateTime>
 #include <QElapsedTimer>
 #include <QEventLoop>
 #include <QObject>
