@@ -33,7 +33,6 @@
 #include <QElapsedTimer>
 #include <QEventLoop>
 #include <QFile>
-#include <QFileInfo>
 
 #include <KAboutData>
 #include <QApplication>
@@ -559,7 +558,8 @@ int main(int argc, char *argv[])
     /***************************************************************************
      * Glorious date/time checking and setting code                            *
      ***************************************************************************/
-    QDateTime startdatetime, enddatetime;
+    QDateTime startdatetime;
+    QDateTime enddatetime;
 
     // Handle case with either date or end-date unspecified
     if (!parser.isSet(QStringLiteral("end-date")) && !parser.isSet(QStringLiteral("show-next")) && parser.isSet(QStringLiteral("date"))) {
